# Branch-screening tests for the L0-penalized least-square problem

This repository contains numerical procedures linked to the paper

**> ADD CITATION**

If you encounter a bug or something unexpected, please let me know by raising an issue on the project page or by contacting me by email at `theo.guyard@insa-rennes.fr`.

## Requirements

This repository works with Julia v1.5+. Please refer to the [Julia download page](https://julialang.org/downloads/) for install instructions.

Dependencies :
* [JuMP.jl](https://github.com/jump-dev/JuMP.jl)
* [CPLEX.jl](https://github.com/jump-dev/CPLEX.jl)
* [Distributions.jl](https://github.com/JuliaStats/Distributions.jl)
* [StatsBase](https://github.com/JuliaStats/StatsBase.jl)

Our code works with the CPLEX solver through [CPLEX.jl](https://github.com/jump-dev/CPLEX.jl). You cannot use CPLEX without having purchased and installed a copy of CPLEX Optimization Studio from [IBM](https://www.ibm.com). However, CPLEX is available for free to [academics and students](https://community.ibm.com/community/user/datascience/blogs/xavier-nodet1/2020/07/09/cplex-free-for-students). We recommend to follow carefully the install instructions described at [CPLEX.jl](https://github.com/jump-dev/CPLEX.jl).

## Install instructions

1. Clone the repository
```bash
git clone https://gitlab.insa-rennes.fr/Theo.Guyard/bnb-screening.git
```

2. Enter in the project folder
```bash
cd bnb-screening
```

3. Ensure that Julia v1.5+ is installed
```bash
julia -v
> julia version 1.5.3 (or higher)
```

4. Install dependencies using [Julia's Pkg](https://docs.julialang.org/en/v1/stdlib/Pkg/) in REPL mode
```julia
(@v1.5) pkg> activate .
(@v1.5) pkg> add JuMP
(@v1.5) pkg> add CPLEX
(@v1.5) pkg> add Distributions
(@v1.5) pkg> add StatsBase
```

## ICASSP experiments

Experiments presented in the paper corresponding to this repository are located in the folder `bnb-screening/exp/ICASSP/`. The available experiment are 
* `performances.jl` corresponding to table 1

Run experiments directly from the project root folder :
```bash
julia --project=. -t 1 exp/ICASSP/performances.jl
```

The `--project=.` argument installs package dependencies if needed. The flag `-t 1` restricts computations to only 1 CPU core in order to avoid bias due to parallelization capabilities. Logs are saved in the same folder as `performances.jl`. You can edit the experimental setup directly in the script, which is well commented.

## Running demo examples

The `example` folder contains portions of code explaining how to use our package.

## Licence

This software is distributed under the [MIT Licence](https://mit-license.org).

## Cite this work

If you use this package for your own work, please consider citing it as :

**ADD CITATION**
